const c = require("centra");
const path = require("path");
const fs = require("fs");

const CLIENT_ID = process.env.SPOTIFY_CLIENT_ID
const CLIENT_SECRET = process.env.SPOTIFY_CLIENT_SECRET
const cachePath = path.join(".", "data", "spotify.json")

const getCachedToken = () => {
    if (!fs.existsSync(cachePath)) {
        fs.writeFileSync(cachePath, "{}", "utf-8")
        return null;
    }
    const data = fs.readFileSync(cachePath)
    const jsonData = JSON.parse(data);
    if (!jsonData.access_token || !jsonData.expiryTime) {
        return null;
    }
    const currTime = new Date();
    const expires = new Date(jsonData.expiryTime)
    if (currTime > expires) {
        return null;
    }
    return jsonData;
}

const cacheToken = (token) => {
    const expiryTime = new Date();
    expiryTime.setHours(expiryTime.getHours() + 1);
    token.expiryTime = expiryTime;
    fs.writeFileSync(cachePath, JSON.stringify(token), "utf-8");
}

const fetchToken = () => {
    return c("https://accounts.spotify.com/api/token", "POST")
    .header("Authorization", `Basic ${new Buffer.from(CLIENT_ID + ":" + CLIENT_SECRET).toString("base64")}`)
    .body({"grant_type": "client_credentials"}, "form")
    .send().then((res) => res.json())
    .then((data) => {
        cacheToken(data);
        return data;
    })
}

const getActiveToken = async () => {
    const cached = getCachedToken();
    if (cached) {
        return cached;
    }
    const newToken = await fetchToken()
    console.log("AAAA", newToken);
    return newToken;
}

module.exports = { getActiveToken }