const express = require('express');
const fs = require('fs');
const path = require('path');
const cors = require('cors');

const app = express();
const PORT = 3111

require('dotenv').config()

const LOADED_MODULES = []

const loadModules = (app) => {
    const modulesDir = path.join(__dirname, "modules");
    fs.readdirSync(modulesDir).forEach(file => {
        if (path.extname(file) === ".js") {
            console.log("[Module Loader] >> Starting loading module: " + file)
            const filePath = path.join(modulesDir, file);
            const module = require(filePath);
            const modulePath = `/${path.basename(file, path.extname(file))}`;
            app.use(modulePath, module);
            LOADED_MODULES.push(file);
            console.log("[Module Loader] >> Loaded module: " + file)
        }
    })
}

console.log("[Module Loader] >> Starting... ")
loadModules(app)
console.log("[Module Loader] >> Finished. Loaded " + LOADED_MODULES.length + " modules successfully.")

app.set('trust proxy', true); // Enable if behind a reverse proxy
// app.use(cors())

app.get("/", (req, res) => {
    res.send("Ellie Comms WebService. Modular API")
})

app.get("/modules", (req, res) => {
    res.json({success: true, modules: LOADED_MODULES})
})

app.listen(PORT, () => {
    console.log(`Ellie Comms WebService is running on port ${PORT}.`)
})